@@ -3,7 +3,8 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.23';
+$SIG{__WARN__} = sub { confess(shift); };
+our $VERSION = '1.24';
 
 use Carp;
 use Exporter;
@@ -260,7 +261,7 @@ sub recsep {
         $fh = $self->_binmode_handle($file);
     };
 
-    if ($@ || ! $fh){
+    if ($@ || -z $fh){
 
         # we've got an empty file...
         # we'll set recsep to the local platform's
